@@ -18,7 +18,7 @@ def dev_urandom_entropy(numbytes):
 	"""
 	return os.urandom(numbytes)
 
-def dev_random_entropy(numbytes, fallback_to_urandom=False):
+def dev_random_entropy(numbytes, fallback_to_urandom=True):
 	""" Reads random bytes from the /dev/random entropy pool.
 
 		NOTE: /dev/random is a blocking pseudorandom number generator.
